@@ -917,8 +917,8 @@ public:
         std::string r = indent;
         r += "print";
         r += " ";
-        if (x.n_values > 0 && is_a<ASR::StringFormat_t>(*x.m_values[0])) {
-            ASR::StringFormat_t *sf = down_cast<ASR::StringFormat_t>(x.m_values[0]);
+        if (is_a<ASR::StringFormat_t>(*x.m_text)) {
+            ASR::StringFormat_t *sf = down_cast<ASR::StringFormat_t>(x.m_text);
             if(sf->m_fmt){
                 visit_expr(*(sf->m_fmt));
                 if (is_a<ASR::StringConstant_t>(*sf->m_fmt)
@@ -929,13 +929,14 @@ public:
             } else {
                 r += "*";
             }
-        } else {
+        } else if (ASR::is_a<ASR::Character_t>(*ASRUtils::expr_type(x.m_text))) {
             r += "*";
-        }
-        for (size_t i = 0; i < x.n_values; i++) {
             r += ", ";
-            visit_expr(*x.m_values[i]);
+            visit_expr(*x.m_text);
             r += src;
+        } else {
+            throw CodeGenError("print statment supported for stringformat and single character argument",
+                x.base.base.loc);
         }
         handle_line_truncation(r, 2);
         r += "\n";
@@ -1259,6 +1260,14 @@ public:
         switch ( x.m_sub_intrinsic_id ) {
             SET_INTRINSIC_SUBROUTINE_NAME(RandomNumber, "random_number");
             SET_INTRINSIC_SUBROUTINE_NAME(RandomInit, "random_init");
+            SET_INTRINSIC_SUBROUTINE_NAME(RandomSeed, "random_seed");
+            SET_INTRINSIC_SUBROUTINE_NAME(GetCommand, "get_command");
+            SET_INTRINSIC_SUBROUTINE_NAME(GetCommandArgument, "get_command_argument");
+            SET_INTRINSIC_SUBROUTINE_NAME(GetEnvironmentVariable, "get_environment_variable");
+            SET_INTRINSIC_SUBROUTINE_NAME(ExecuteCommandLine, "execute_command_line");
+            SET_INTRINSIC_SUBROUTINE_NAME(Srand, "srand");
+            SET_INTRINSIC_SUBROUTINE_NAME(SystemClock, "system_clock");
+            SET_INTRINSIC_SUBROUTINE_NAME(DateAndTime, "date_and_time");
             default : {
                 throw LCompilersException("IntrinsicImpureSubroutine: `"
                     + ASRUtils::get_intrinsic_name(x.m_sub_intrinsic_id)
@@ -1300,6 +1309,8 @@ public:
         else if(intrinsic_func_name == "LogGamma") intrinsic_func_name = "log_gamma";
         else if(intrinsic_func_name == "SetExponent") intrinsic_func_name = "set_exponent";
         else if(intrinsic_func_name == "Mergebits") intrinsic_func_name = "merge_bits";
+        else if(intrinsic_func_name == "StringLenTrim") intrinsic_func_name = "len_trim";
+        else if(intrinsic_func_name == "StringTrim") intrinsic_func_name = "trim";
         visit_IntrinsicElementalFunction_helper(out, intrinsic_func_name, x);
     }
 
