@@ -68,6 +68,12 @@ intrinsic_funcs_args = {
             "ret_type_arg_idx": 3
         },
     ],
+    "MoveAlloc": [
+        {
+            "args": [("any", "any")],
+            "ret_type_arg_idx": 0
+        },
+    ],
     "Leadz": [
         {
             "args": [("int",)],
@@ -263,6 +269,12 @@ intrinsic_funcs_args = {
             "return": "logical"
         },
     ],
+    "OutOfRange": [
+        {
+            "args": [("int", "real", "bool"), ("real", "real", "bool"), ("int", "int", "bool"), ("real", "int", "bool")],
+            "return": "logical"
+        },
+    ],
     "StorageSize": [
         {
             "args": [("any",)],
@@ -301,6 +313,12 @@ intrinsic_funcs_args = {
             "return": "logical",
         }
     ],
+    "SameTypeAs": [
+        {
+            "args": [("any", "any")],
+            "return": "logical"
+        }
+    ],
     "Nint": [
         {
             "args": [("real",)],
@@ -789,32 +807,52 @@ intrinsic_funcs_args = {
            "ret_type_arg_idx": 0,
            "same_kind_arg": 2
        },
-   ],
-   "Dshiftr": [
-       {
-           "args": [("int", "int", "int",)],
-           "ret_type_arg_idx": 0
-       },
-   ],
-   "Popcnt": [
-       {
-           "args": [("int",)],
-           "return": "int32",
-       },
-   ],
-   "Poppar": [
-       {
-           "args": [("int",)],
-           "return": "int32",
-       },
-   ],
+    ],
+    "Dshiftr": [
+        {
+            "args": [("int", "int", "int",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "Popcnt": [
+        {
+            "args": [("int",)],
+            "return": "int32",
+        },
+    ],
+    "Poppar": [
+        {
+            "args": [("int",)],
+            "return": "int32",
+        },
+    ],
     "Real": [
-       {
-           "args": [("int",), ("real",), ("complex",)],
-           "return": "real32",
-           "kind_arg": True,
-       },
-   ],
+        {
+            "args": [("int",), ("real",), ("complex",)],
+            "return": "real32",
+            "kind_arg": True,
+        },
+    ],
+    "Int": [
+        {
+            "args": [("int",), ("real",), ("complex",)],
+            "return": "int32",
+            "kind_arg": True
+        }
+    ],
+    "StringLenTrim": [
+        {
+            "args": [("char",)],
+            "return": "int32",
+            "kind_arg": True
+        }
+    ],
+    "StringTrim": [
+        {
+            "args": [("char",)],
+            "ret_type_arg_idx": 0
+        }
+    ],
 }
 
 skip_create_func = ["Partition"]
@@ -833,6 +871,8 @@ compile_time_only_fn = [
     "Kind",
     "MaxExponent",
     "MinExponent",
+    "SameTypeAs",
+    "Digits",
 ]
 
 type_to_asr_type_check = {
