@@ -67,13 +67,16 @@ inline std::string get_intrinsic_name(int64_t x) {
         INTRINSIC_NAME_CASE(CommandArgumentCount)
         INTRINSIC_NAME_CASE(Spacing)
         INTRINSIC_NAME_CASE(Modulo)
+        INTRINSIC_NAME_CASE(OutOfRange)
         INTRINSIC_NAME_CASE(BesselJ0)
         INTRINSIC_NAME_CASE(BesselJ1)
         INTRINSIC_NAME_CASE(BesselJN)
         INTRINSIC_NAME_CASE(BesselY0)
         INTRINSIC_NAME_CASE(BesselY1)
         INTRINSIC_NAME_CASE(BesselYN)
+        INTRINSIC_NAME_CASE(SameTypeAs)
         INTRINSIC_NAME_CASE(Mvbits)
+        INTRINSIC_NAME_CASE(MoveAlloc)
         INTRINSIC_NAME_CASE(Merge)
         INTRINSIC_NAME_CASE(Mergebits)
         INTRINSIC_NAME_CASE(Shiftr)
@@ -119,6 +122,8 @@ inline std::string get_intrinsic_name(int64_t x) {
         INTRINSIC_NAME_CASE(SelectedCharKind)
         INTRINSIC_NAME_CASE(Adjustl)
         INTRINSIC_NAME_CASE(Adjustr)
+        INTRINSIC_NAME_CASE(StringLenTrim)
+        INTRINSIC_NAME_CASE(StringTrim)
         INTRINSIC_NAME_CASE(Ichar)
         INTRINSIC_NAME_CASE(Char)
         INTRINSIC_NAME_CASE(Achar)
@@ -185,6 +190,7 @@ inline std::string get_intrinsic_name(int64_t x) {
         INTRINSIC_NAME_CASE(SymbolicLogQ)
         INTRINSIC_NAME_CASE(SymbolicSinQ)
         INTRINSIC_NAME_CASE(SymbolicGetArgument)
+        INTRINSIC_NAME_CASE(Int)
         default : {
             throw LCompilersException("pickle: intrinsic_id not implemented");
         }
@@ -216,6 +222,8 @@ namespace IntrinsicElementalFunctionRegistry {
             {&Fix::instantiate_Fix, &Fix::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Sin),
             {&Sin::instantiate_Sin, &Sin::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::OutOfRange),
+            {&OutOfRange::instantiate_OutOfRange, &OutOfRange::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::BesselJ0),
             {&BesselJ0::instantiate_BesselJ0, &BesselJ0::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::BesselJ1),
@@ -287,7 +295,7 @@ namespace IntrinsicElementalFunctionRegistry {
         {static_cast<int64_t>(IntrinsicElementalFunctions::CompilerVersion),
             {nullptr, &CompilerVersion::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::CommandArgumentCount),
-            {nullptr, &CommandArgumentCount::verify_args}},
+            {&CommandArgumentCount::instantiate_CommandArgumentCount, &CommandArgumentCount::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Spacing),
             {&Spacing::instantiate_Spacing, &Spacing::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Modulo),
@@ -296,10 +304,14 @@ namespace IntrinsicElementalFunctionRegistry {
             {&BesselJN::instantiate_BesselJN, &BesselJN::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::BesselYN),
             {&BesselYN::instantiate_BesselYN, &BesselYN::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::SameTypeAs),
+            {nullptr, &SameTypeAs::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Merge),
             {&Merge::instantiate_Merge, &Merge::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Mvbits),
             {&Mvbits::instantiate_Mvbits, &Mvbits::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::MoveAlloc),
+            {&MoveAlloc::instantiate_MoveAlloc, &MoveAlloc::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Mergebits),
             {&Mergebits::instantiate_Mergebits, &Mergebits::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Shiftr),
@@ -308,6 +320,10 @@ namespace IntrinsicElementalFunctionRegistry {
             {&Adjustl::instantiate_Adjustl, &Adjustl::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Adjustr),
             {&Adjustr::instantiate_Adjustr, &Adjustr::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::StringLenTrim),
+            {&StringLenTrim::instantiate_StringLenTrim, &StringLenTrim::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::StringTrim),
+            {&StringTrim::instantiate_StringTrim, &StringTrim::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Ichar),
             {&Ichar::instantiate_Ichar, &Ichar::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Char),
@@ -530,6 +546,10 @@ namespace IntrinsicElementalFunctionRegistry {
             {nullptr, &SymbolicSinQ::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::SymbolicGetArgument),
             {nullptr, &SymbolicGetArgument::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::CommandArgumentCount),
+            {&CommandArgumentCount::instantiate_CommandArgumentCount, &CommandArgumentCount::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Int),
+            {&Int::instantiate_Int, &Int::verify_args}},
     };
 
     static const std::map<int64_t, std::string>& intrinsic_function_id_to_name = {
@@ -625,6 +645,8 @@ namespace IntrinsicElementalFunctionRegistry {
             "cosd"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Tand),
             "tand"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::OutOfRange),
+            "out_of_range"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::BesselJ0),
             "bessel_j0"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::BesselJ1),
@@ -637,10 +659,14 @@ namespace IntrinsicElementalFunctionRegistry {
             "bessel_jn"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::BesselYN),
             "bessel_yn"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::SameTypeAs),
+            "same_type_as"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Merge),
             "merge"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Mvbits),
             "mvbits"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::MoveAlloc),
+            "move_alloc"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Mergebits),
             "mergebits"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Shiftr),
@@ -651,6 +677,10 @@ namespace IntrinsicElementalFunctionRegistry {
             "adjustl"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Adjustr),
             "adjustr"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::StringLenTrim),
+            "len_trim"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::StringTrim),
+            "trim"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Ichar),
             "ichar"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Char),
@@ -865,6 +895,8 @@ namespace IntrinsicElementalFunctionRegistry {
             "SymbolicSinQ"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::SymbolicGetArgument),
             "SymbolicGetArgument"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Int),
+            "int"},
     };
 
 
@@ -886,6 +918,7 @@ namespace IntrinsicElementalFunctionRegistry {
                 {"bessel_j1", {&BesselJ1::create_BesselJ1, &BesselJ1::eval_BesselJ1}},
                 {"bessel_y0", {&BesselY0::create_BesselY0, &BesselY0::eval_BesselY0}},
                 {"bessel_y1", {&BesselY1::create_BesselY1, &BesselY1::eval_BesselY1}},
+                {"same_type_as", {&SameTypeAs::create_SameTypeAs, &SameTypeAs::eval_SameTypeAs}},
                 {"asind", {&Asind::create_Asind, &Asind::eval_Asind}},
                 {"acosd", {&Acosd::create_Acosd, &Acosd::eval_Acosd}},
                 {"atand", {&Atand::create_Atand, &Atand::eval_Atand}},
@@ -917,12 +950,14 @@ namespace IntrinsicElementalFunctionRegistry {
                 {"isnan", {&Isnan::create_Isnan, &Isnan::eval_Isnan}},
                 {"nearest", {&Nearest::create_Nearest, &Nearest::eval_Nearest}},
                 {"compiler_version", {&CompilerVersion::create_CompilerVersion, &CompilerVersion::eval_CompilerVersion}},
+                {"command_argument_count", {&CommandArgumentCount::create_CommandArgumentCount, nullptr}},
                 {"spacing", {&Spacing::create_Spacing, &Spacing::eval_Spacing}},
                 {"modulo", {&Modulo::create_Modulo, &Modulo::eval_Modulo}},
                 {"bessel_jn", {&BesselJN::create_BesselJN, &BesselJN::eval_BesselJN}},
                 {"bessel_yn", {&BesselYN::create_BesselYN, &BesselYN::eval_BesselYN}},
                 {"merge", {&Merge::create_Merge, &Merge::eval_Merge}},
                 {"mvbits", {&Mvbits::create_Mvbits, &Mvbits::eval_Mvbits}},
+                {"move_alloc", {&MoveAlloc::create_MoveAlloc, &MoveAlloc::eval_MoveAlloc}},
                 {"merge_bits", {&Mergebits::create_Mergebits, &Mergebits::eval_Mergebits}},
                 {"shiftr", {&Shiftr::create_Shiftr, &Shiftr::eval_Shiftr}},
                 {"rshift", {&Rshift::create_Rshift, &Rshift::eval_Rshift}},
@@ -978,6 +1013,8 @@ namespace IntrinsicElementalFunctionRegistry {
                 {"max0", {&Max::create_Max, &Max::eval_Max}},
                 {"adjustl", {&Adjustl::create_Adjustl, &Adjustl::eval_Adjustl}},
                 {"adjustr", {&Adjustr::create_Adjustr, &Adjustr::eval_Adjustr}},
+                {"len_trim", {&StringLenTrim::create_StringLenTrim, &StringLenTrim::eval_StringLenTrim}},
+                {"trim", {&StringTrim::create_StringTrim, &StringTrim::eval_StringTrim}},
                 {"ichar", {&Ichar::create_Ichar, &Ichar::eval_Ichar}},
                 {"char", {&Char::create_Char, &Char::eval_Char}},
                 {"achar", {&Achar::create_Achar, &Achar::eval_Achar}},
@@ -987,6 +1024,7 @@ namespace IntrinsicElementalFunctionRegistry {
                 {"ishftc", {&Ishftc::create_Ishftc, &Ishftc::eval_Ishftc}},
                 {"radix", {&Radix::create_Radix, &Radix::eval_Radix}},
                 {"is_contiguous", {&IsContiguous::create_IsContiguous, &IsContiguous::eval_IsContiguous}},
+                {"out_of_range", {&OutOfRange::create_OutOfRange, &OutOfRange::eval_OutOfRange}},
                 {"storage_size", {&StorageSize::create_StorageSize, &StorageSize::eval_StorageSize}},
                 {"scale", {&Scale::create_Scale, &Scale::eval_Scale}},
                 {"dprod", {&Dprod::create_Dprod, &Dprod::eval_Dprod}},
@@ -1037,6 +1075,7 @@ namespace IntrinsicElementalFunctionRegistry {
                 {"LogQ", {&SymbolicLogQ::create_SymbolicLogQ, &SymbolicLogQ::eval_SymbolicLogQ}},
                 {"SinQ", {&SymbolicSinQ::create_SymbolicSinQ, &SymbolicSinQ::eval_SymbolicSinQ}},
                 {"GetArgument", {&SymbolicGetArgument::create_SymbolicGetArgument, &SymbolicGetArgument::eval_SymbolicGetArgument}},
+                {"int", {&Int::create_Int, &Int::eval_Int}},
     };
 
     static inline bool is_intrinsic_function(const std::string& name) {
